@@ -391,14 +391,8 @@ static void print_variables(int include_values, int esc, bool shorten_ok, int sc
     }
 }
 
-
-
-/**
-   The set builtin. Creates, updates and erases environment variables
-   and environemnt variable arrays.
-*/
-static int builtin_set(parser_t &parser, io_streams_t &streams, wchar_t **argv)
-{
+/// The set builtin creates, updates, and erases (removes, deletes) variables.
+int builtin_set(parser_t &parser, io_streams_t &streams, wchar_t **argv) {
     wgetopter_t w;
     /** Variables used for parsing the argument list */
     const struct woption long_options[] =
