@@ -450,15 +450,16 @@ class pcre2_matcher_t: public string_matcher_t
     const wchar_t *argv0;
     compiled_regex_t regex;
 
-    int report_match(const wchar_t *arg, int pcre2_rc)
-    {
-        // Return values: -1 = error, 0 = no match, 1 = match
-        if (pcre2_rc == PCRE2_ERROR_NOMATCH)
-        {
-            if (opts.invert_match && !opts.quiet)
-            {
-                streams.out.append(arg);
-                streams.out.push_back(L'\n');
+    int report_match(const wchar_t *arg, int pcre2_rc) {
+        // Return values: -1 = error, 0 = no match, 1 = match.
+        if (pcre2_rc == PCRE2_ERROR_NOMATCH) {
+            if (opts.invert_match && !opts.quiet) {
+                if (opts.index) {
+                    streams.out.append_format(L"1 %lu\n", wcslen(arg));
+                } else {
+                    streams.out.append(arg);
+                    streams.out.push_back(L'\n');
+                }
             }
 
             return opts.invert_match ? 1 : 0;
