@@ -25,6 +25,13 @@
 #include "config.h"
 #include "fallback.h"
 
+// Define a symbol we can use elsewhere in our code to determine if we're being built on MS Windows
+// under Cygwin.
+#if defined(_WIN32) || defined(_WIN64) || defined(WIN32) || defined(__CYGWIN__) || \
+    defined(__WIN32__)
+#define OS_IS_CYGWIN
+#endif
+
 /**
    Avoid writing the type name twice in a common "static_cast-initialization".
    Caveat: This doesn't work with type names containing commas!
@@ -196,6 +203,10 @@ extern const wchar_t *program_name;
 void read_ignore(int fd, void *buff, size_t count);
 void write_ignore(int fd, const void *buff, size_t count);
 
+/// Set to false at run-time if it's been determined we can't trust the last modified timestamp on
+/// the tty.
+extern bool has_working_tty_timestamps;
+
 /**
    This macro is used to check that an input argument is not null. It
    is a bit lika a non-fatal form of assert. Instead of exit-ing on
@@ -752,13 +763,9 @@ wchar_t *quote_end(const wchar_t *in);
 */
 void error_reset();
 
-/**
-   This function behaves exactly like a wide character equivalent of
-   the C function setlocale, except that it will also try to detect if
-   the user is using a Unicode character set, and if so, use the
-   unicode ellipsis character as ellipsis, instead of '$'.
-*/
-wcstring wsetlocale(int category, const wchar_t *locale);
+/// This function should be called after calling `setlocale()` to perform fish specific locale
+/// initialization.
+void fish_setlocale();
 
 /**
    Checks if \c needle is included in the list of strings specified. A warning is printed if needle is zero.
