@@ -29,6 +29,7 @@
 #include "fallback.h"
 #include "wutil.h" // IWYU pragma: keep - needed for wgettext
 #include "common.h"
+#include "env.h"
 #include "output.h"
 
 static int writeb_internal(char c);
@@ -37,14 +38,8 @@ static int writeb_internal(char c);
 /**
  The function used for output
  */
-
 static int (*out)(char c) = &writeb_internal;
 
-/**
- Name of terminal
- */
-static wcstring current_term;
-
 /* Whether term256 and term24bit are supported */
 static color_support_t color_support = 0;
 
@@ -554,29 +549,13 @@ rgb_color_t parse_color(const wcstring &val, bool is_background)
     return result;
 }
 
-void output_set_term(const wcstring &term)
-{
-    current_term.assign(term);
-}
-
-const wchar_t *output_get_term()
-{
-    return current_term.empty() ? L"<unknown>" : current_term.c_str();
-}
-
-void writembs_check(char *mbs, const char *mbs_name, const char *file, long line)
-{
-    if (mbs != NULL)
-    {
+void writembs_check(char *mbs, const char *mbs_name, const char *file, long line) {
+    if (mbs != NULL) {
         tputs(mbs, 1, &writeb);
-    }
-    else
-    {
-        debug( 0, _(L"Tried to use terminfo string %s on line %ld of %s, which is undefined in terminal of type \"%ls\". Please report this error to %s"),
-              mbs_name,
-              line,
-              file,
-              output_get_term(),
-              PACKAGE_BUGREPORT);
+    } else {
+        env_var_t term = env_get_string(L"TERM");
+        debug(0, _(L"Tried to use terminfo string %s on line %ld of %s, which is undefined in "
+                   L"terminal of type \"%ls\". Please report this error to %s"),
+              mbs_name, line, file, term.c_str(), PACKAGE_BUGREPORT);
     }
 }
